==> mfc-api-model-0.1.2-sources.jar: com/valor/mfc/vms/api/model/notice/NoticeDO.java <==
package com.valor.mfc.vms.api.model.notice;


import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * File        : valormotorserver:${FILENAME}
 * Description :
 * Author      : Frank
 * Created     : 2015/9/4
 */

public class NoticeDO extends AbstractPrintable {

    private Long noticeId;
    private String region;
    private String language;
    private ENoticeType noticeType;   //类型
    private ENoticeFrequency frequency;    //展示频率
    private int priority;     //优先级
    private String title;        //标题
    private String message;      //消息内容
    private String image;        //图片
    private String url;          //url
    private String startTime;    //开始时间(格式:yyyymmdd)
    private String endTime;      //结束时间(格式:yyyymmdd)
    private ENoticeStatus status;
    private String updateTime;
    private String imageChecksum;
    private String startTime2;
    private String endTime2;
    private int userType;
    private int loginType;
    private int deviceType;     //设备类型
    private int serviceStatus;
    private String productModel;

    /////////////////////////////////////////////////////


    public int getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(int deviceType) {
        this.deviceType = deviceType;
    }

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public ENoticeType getNoticeType() {
        return noticeType;
    }

    public void setNoticeType(ENoticeType noticeType) {
        this.noticeType = noticeType;
    }

    public void setNoticeTypeStr(String noticeType) {
        this.noticeType = ENoticeType.valueOf(noticeType);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public ENoticeFrequency getFrequency() {
        return frequency;
    }

    public void setFrequency(ENoticeFrequency frequency) {
        this.frequency = frequency;
    }

    public void setFrequencyStr(String frequency) {
        this.frequency = ENoticeFrequency.valueOf(frequency);
    }

    public int getPriority() {
        return priority;
    }

    public void setPriority(int priority) {
        this.priority = priority;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public ENoticeStatus getStatus() {
        return status;
    }

    public void setStatus(ENoticeStatus status) {
        this.status = status;
    }

    public void setStatusStr(String status) {
        this.status = ENoticeStatus.valueOf(status);
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getImageChecksum() {
        return imageChecksum;
    }

    public void setImageChecksum(String imageChecksum) {
        this.imageChecksum = imageChecksum;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getStartTime2() {
        return startTime2;
    }

    public void setStartTime2(String startTime2) {
        this.startTime2 = startTime2;
    }

    public String getEndTime2() {
        return endTime2;
    }

    public void setEndTime2(String endTime2) {
        this.endTime2 = endTime2;
    }

    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public int getLoginType() {
        return loginType;
    }

    public void setLoginType(int loginType) {
        this.loginType = loginType;
    }

    public int getServiceStatus() {
        return serviceStatus;
    }

    public void setServiceStatus(int serviceStatus) {
        this.serviceStatus = serviceStatus;
    }

    public String getProductModel() {
        return productModel;
    }

    public void setProductModel(String productModel) {
        this.productModel = productModel;
    }
}

==> mfc-api-model-0.1.5-sources.jar: com/valor/mfc/vms/api/model/notice/NoticeDO.java <==
package com.valor.mfc.vms.api.model.notice;


import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * File        : valormotorserver:${FILENAME}
 * Description :
 * Author      : Frank
 * Created     : 2015/9/4
 */

public class NoticeDO extends AbstractPrintable {

    private Long noticeId;
    private String region;
    private String language;
    private ENoticeType noticeType;   //类型
    private ENoticeFrequency frequency;    //展示频率
    private int priority;     //优先级
    private String title;        //标题
    private String message;      //消息内容
    private String image;        //图片
    private String url;          //url
    private String startTime;    //开始时间(格式:yyyymmdd)
    private String endTime;      //结束时间(格式:yyyymmdd)
    private ENoticeStatus status;
    private String updateTime;
    private String imageChecksum;
    private String startTime2;
    private String endTime2;
    private int userType;
    private int loginType;
    private int deviceType;     //设备类型
    private int serviceStatus;
    private String productModel;
    private int sourceChannel;

    /////////////////////////////////////////////////////


    public int getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(int deviceType) {
        this.deviceType = deviceType;
    }

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public ENoticeType getNoticeType() {
        return noticeType;
    }

    public void setNoticeType(ENoticeType noticeType) {
        this.noticeType = noticeType;
    }

    public void setNoticeTypeStr(String noticeType) {
        this.noticeType = ENoticeType.valueOf(noticeType);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public ENoticeFrequency getFrequency() {
        return frequency;
    }

    public void setFrequency(ENoticeFrequency frequency) {
        this.frequency = frequency;
    }

    public void setFrequencyStr(String frequency) {
        this.frequency = ENoticeFrequency.valueOf(frequency);
    }

    public int getPriority() {
        return priority;
    }

    public void setPriority(int priority) {
        this.priority = priority;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public ENoticeStatus getStatus() {
        return status;
    }

    public void setStatus(ENoticeStatus status) {
        this.status = status;
    }

    public void setStatusStr(String status) {
        this.status = ENoticeStatus.valueOf(status);
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getImageChecksum() {
        return imageChecksum;
    }

    public void setImageChecksum(String imageChecksum) {
        this.imageChecksum = imageChecksum;
    }

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getStartTime2() {
        return startTime2;
    }

    public void setStartTime2(String startTime2) {
        this.startTime2 = startTime2;
    }

    public String getEndTime2() {
        return endTime2;
    }

    public void setEndTime2(String endTime2) {
        this.endTime2 = endTime2;
    }

    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public int getLoginType() {
        return loginType;
    }

    public void setLoginType(int loginType) {
        this.loginType = loginType;
    }

    public int getServiceStatus() {
        return serviceStatus;
    }

    public void setServiceStatus(int serviceStatus) {
        this.serviceStatus = serviceStatus;
    }

    public String getProductModel() {
        return productModel;
    }

    public void setProductModel(String productModel) {
        this.productModel = productModel;
    }

    public int getSourceChannel() { return sourceChannel; }

    public void setSourceChannel(int sourceChannel) { this.sourceChannel = sourceChannel; }
}
